@@ -151,7 +151,7 @@ is_container_standard_prop (const char *name,
                             const char *upnp_class)
 {
         return g_strcmp0 (upnp_class, "object.container.storageFolder") == 0 &&
-               strcmp (namespace, "upnp") == 0 &&
+               g_strcmp0 (namespace, "upnp") == 0 &&
                strcmp (name, "storageUsed") == 0;
 }
 
@@ -402,7 +402,7 @@ gupnp_didl_lite_writer_class_init (GUPnPDIDLLiteWriterClass *klass)
         g_type_class_add_private (klass, sizeof (GUPnPDIDLLiteWriterPrivate));
 
         /**
-         * GUPnPDIDLLiteWriter:xml-node
+         * GUPnPDIDLLiteWriter:xml-node:
          *
          * The pointer to root node in XML document.
          **/
@@ -419,7 +419,7 @@ gupnp_didl_lite_writer_class_init (GUPnPDIDLLiteWriterClass *klass)
                                        G_PARAM_STATIC_BLURB));
 
         /**
-         * GUPnPDIDLLiteWriter:language
+         * GUPnPDIDLLiteWriter:language:
          *
          * The language the DIDL-Lite fragment is in.
          *
